# Veracity LRS

## About

Veracity LRS is an xAPI compatible Learning Record Store. It is fully conformant with version 1.0.3 and 2.0 of the xAPI specification. It uses MongoDB as its primary database, and can accelerate queries with an optional ElasticSearch connection. 

## Licensing 

Veracity LRS will run in "lite" mode unless a license key is provided in the environment. Please fill out a new ticket at https://veracitytech.zohodesk.com/portal/en/newticket to obtain an enterprise license key. 

## Configuration
While typically settings are read from the .env file, when running as a container settings are read from environment variables. To facilate startup in a containerized environment, this container will reset the administrative login credentials on each start. The admin credentials are controlled by the admin_email and admin_pass settings. Be sure to safeguard these in your deployment scripts. Please see a full discussion of configuration options here: https://veracitytech.zohodesk.com/portal/en/kb/articles/configuration#Setting_Configuration_Values

```
mongoServer=mongodb://localhost
redisServer=redis://localhost
host=localhost
port=3005
displayPort=3005
protocol=http
admin_email=tom@example.com
admin_pass=1234
domainRouting=false
adminDBName=VTCLRS
SERVER_SECRET=youAbsolutelyMustChangeThis
selfServiceAccounts=true
inProcessJobs=true
email_user=rob@veracity.it
email_pass=nope
email_server="smtp.gmail.com"
email_to=rob@veracity.it
createSampleLRS=true
license=xxxxxxxxxx    //don't supply any value to run in lite mode
```

1. *mongoServer*: the connection to mongodb
1. *redisServer*: the connection to Redis. Leaving this blank or leaving it out of the file will disable redis features like websockets and rate limiting
1. *host*: the actual host name for this server. Could be localhost. In dev, I use local.veracity.it
1. *port*: the actual service port on which the server runs. Not necessarily the one users see
1. *displayPort*: the port the user sees, if we're behind NGinx or something
1. *protocol*: either http or https. Controls how absolute links to self are rendered.
1. *admin_email*: The email address for the super admin login
1. *admin_pass*: the associated password for the super admin
1. *domainRouting*: do we use a host header domain for xapi and learner links, or do we include it in path
1. *adminDBName*: the name of the mongodb db where we store system stuff
1. *SERVER_SECERT*: a string used to encrypt some data. Can also be used as a super password to log in as any user
1. *development*: signals to the system that we are in dev, so the load balancer is off, some additional logging happens
1. *production*: signals to the system that we are built into the single module. Drastically changes how templates are rendered
1. *selfServiceAccounts*: render the ui and hook up the routes for users to create their own accounts
1. *inProcessJobs*: the job queue processor will run in the same process as the web server
1. *email_user*: the username to use when sending an email.
1. *email_pass*: the password to use to send an email
1. *email_server*: the outgoing mail server to use
1. *email_to*: where to send the "contact us" emails
1. *googleAnalyticsID*: the google analytics account to use
1. *createSampleLRS*: only works when selfServiceAccounts is true, create a sample LRS full of data for new users

## An Example Docker Compose script

```
version: "3.9"
services:
  veracity:
    image:  veracitylrs/veracitylrs:latest
    depends_on:
      - "mongodb"
    ports:
      - "80:3005"
    environment:
      port: "3005"
      displayPort: "80"
      mongoServer: "mongodb://mongodb:27017"                 
      host: "54.242.40.102"                                             # Set this to the public facing DNS name of the service
      admin_email: "admin@localhost.com"                                # This will be set up on service start
      admin_pass: "98234t9reuiruh"                                      # Choose something secure
  mongodb:
    image: "mongo:latest"
```